@@ -1,8 +1,8 @@
 from PIL import Image
 import numpy as np
 import torch
-from nets.deeplab import DeepLab
-from utils.data import decodePredicts
+from .nets.deeplab import DeepLab
+from .utils.data import decodePredicts
 from torchvision import transforms
 
 
